==> haskell-wai-app-static-3.1.6.1-107-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.1
id: wai-app-static-3.1.6.1-KTzcLIDTGPz9sx59mCxhok
key: wai-app-static-3.1.6.1-KTzcLIDTGPz9sx59mCxhok
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
abi: e9bf4ebe1a89d22d1f598a1d1941dfd8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-app-static-3.1.6.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-app-static-3.1.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/wai-app-static-3.1.6.1
hs-libraries: HSwai-app-static-3.1.6.1-KTzcLIDTGPz9sx59mCxhok
depends:
    base-4.10.1.0 wai-3.2.1.1-CxsYXmrc3SU8ilHGN3PgZ bytestring-0.10.8.2
    http-types-0.9.1-LLq3nvC0GR761npQ3LSltX transformers-0.5.2.0
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ directory-1.3.0.2
    containers-0.5.10.2 time-1.8.0.2
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
    file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
    cryptonite-0.24-KSgqPvW6P2U2g3l2SIl5eS
    memory-0.14.9-6VeLHSFN7gIHTYXihL4eIB
    http-date-0.0.6.1-BIfI1QKDBBCGlG6ZsYiQOY
    blaze-html-0.9.0.1-AJ5BYeepLwbHkN0LWWSQW
    blaze-markup-0.8.0.0-KhGWK8j3xIT2gHtdkKPmyu
    mime-types-0.1.0.7-GpJ8puV91aQIqce5VmolFE
    unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV
    template-haskell-2.12.0.0 zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM
    filepath-1.4.1.2 wai-extra-3.0.20.2-IXlwQkdKfLlGYFrHYk6Qkl
    optparse-applicative-0.14.0.0-15HrL1rhEUQ8kuSXm7AxHM
    warp-3.2.13-6vBFcHpy3uGP3bmgqmhJg
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             wai-3.2.1.1-CxsYXmrc3SU8ilHGN3PgZ=dcc38b24f76cacfb8bf0b44d8596ab32
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             http-types-0.9.1-LLq3nvC0GR761npQ3LSltX=0d554356f4ed969435ba6595d6cdc172
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=5b179f57b538cadc8b677d453ca08cb0
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=cd49072ee3f44d2ed6a40aa4d5cec718
             file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG=60c48eafa794ec5b5f910994f049f250
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH=efe227a7a23c0583e6a2d74f96c7367f
             cryptonite-0.24-KSgqPvW6P2U2g3l2SIl5eS=4f7336c70e37545d54480662c758f0f9
             memory-0.14.9-6VeLHSFN7gIHTYXihL4eIB=65e0a49a4c422385444ca19510423d90
             http-date-0.0.6.1-BIfI1QKDBBCGlG6ZsYiQOY=f105f6117ad0204d183b8268e9d836a5
             blaze-html-0.9.0.1-AJ5BYeepLwbHkN0LWWSQW=aacf4ada2f529531df2388d4874df568
             blaze-markup-0.8.0.0-KhGWK8j3xIT2gHtdkKPmyu=60bf71ffdbd66c0260456518da98a9ef
             mime-types-0.1.0.7-GpJ8puV91aQIqce5VmolFE=dbc6ef116d0af5b7a7e2356daae7662b
             unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV=b12cdae8ac228affcce9703d4cef3dce
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM=71e809b45e9d2afb17d0dfafd165b73c
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             wai-extra-3.0.20.2-IXlwQkdKfLlGYFrHYk6Qkl=1aa7d47ab895d609917d132b70bbb832
             optparse-applicative-0.14.0.0-15HrL1rhEUQ8kuSXm7AxHM=92314de66c39ac99dec61509f5e450d1
             warp-3.2.13-6vBFcHpy3uGP3bmgqmhJg=14dc606ef61dc03d92e06a031617890f
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.6.1-110-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.1
id: wai-app-static-3.1.6.1-55uwCibnb2uLGYAu70znHA
key: wai-app-static-3.1.6.1-55uwCibnb2uLGYAu70znHA
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
abi: c8c1d15ede527df8bc1b0bed905878b7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-app-static-3.1.6.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-app-static-3.1.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/wai-app-static-3.1.6.1
hs-libraries: HSwai-app-static-3.1.6.1-55uwCibnb2uLGYAu70znHA
depends:
    base-4.10.1.0 wai-3.2.1.1-CxsYXmrc3SU8ilHGN3PgZ bytestring-0.10.8.2
    http-types-0.9.1-LLq3nvC0GR761npQ3LSltX transformers-0.5.2.0
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ directory-1.3.0.2
    containers-0.5.10.2 time-1.8.0.2
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
    file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
    cryptonite-0.24-26n9mVTglnwAIizKbDxtWC
    memory-0.14.10-LwCYa6TFutlHfUbiGZd8KU
    http-date-0.0.6.1-BIfI1QKDBBCGlG6ZsYiQOY
    blaze-html-0.9.0.1-AJ5BYeepLwbHkN0LWWSQW
    blaze-markup-0.8.0.0-KhGWK8j3xIT2gHtdkKPmyu
    mime-types-0.1.0.7-GpJ8puV91aQIqce5VmolFE
    unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV
    template-haskell-2.12.0.0 zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM
    filepath-1.4.1.2 wai-extra-3.0.20.2-DnRUnTF4FEV4J88NqlZIRj
    optparse-applicative-0.14.0.0-5Yv3vB6F9Ec49FKuO0i7CD
    warp-3.2.13-6vBFcHpy3uGP3bmgqmhJg
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             wai-3.2.1.1-CxsYXmrc3SU8ilHGN3PgZ=dcc38b24f76cacfb8bf0b44d8596ab32
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             http-types-0.9.1-LLq3nvC0GR761npQ3LSltX=0d554356f4ed969435ba6595d6cdc172
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=5b179f57b538cadc8b677d453ca08cb0
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=cd49072ee3f44d2ed6a40aa4d5cec718
             file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG=60c48eafa794ec5b5f910994f049f250
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH=efe227a7a23c0583e6a2d74f96c7367f
             cryptonite-0.24-26n9mVTglnwAIizKbDxtWC=200c027bd3a4a1992644ead706f50b7b
             memory-0.14.10-LwCYa6TFutlHfUbiGZd8KU=3fa6db0e75ddbe9767a7d9705b7f2f61
             http-date-0.0.6.1-BIfI1QKDBBCGlG6ZsYiQOY=f105f6117ad0204d183b8268e9d836a5
             blaze-html-0.9.0.1-AJ5BYeepLwbHkN0LWWSQW=aacf4ada2f529531df2388d4874df568
             blaze-markup-0.8.0.0-KhGWK8j3xIT2gHtdkKPmyu=60bf71ffdbd66c0260456518da98a9ef
             mime-types-0.1.0.7-GpJ8puV91aQIqce5VmolFE=dbc6ef116d0af5b7a7e2356daae7662b
             unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV=b12cdae8ac228affcce9703d4cef3dce
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM=71e809b45e9d2afb17d0dfafd165b73c
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             wai-extra-3.0.20.2-DnRUnTF4FEV4J88NqlZIRj=c093d019a6d2e188795867d3c360adfa
             optparse-applicative-0.14.0.0-5Yv3vB6F9Ec49FKuO0i7CD=f15e9e49f950ae5cfb701c143a0a1e92
             warp-3.2.13-6vBFcHpy3uGP3bmgqmhJg=14dc606ef61dc03d92e06a031617890f
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
